@@ -26,7 +26,7 @@ def build_macro_classes(BaseClass):
             }
 
         def add_macro_param(self, type_):
-            self.create_output(type_, '')
+            self.create_output(type_=type_, label='')
 
             i = len(self.outputs)-1
             self.actions['remove parameter'][str(i)] = {
@@ -100,7 +100,7 @@ def build_macro_classes(BaseClass):
             # It is coordinated by the input node above.
 
         def add_macro_return(self, type_):
-            self.create_input(type_)
+            self.create_input(type_=type_, label='')
 
             i = len(self.inputs)-1
             self.actions['remove return'][str(i)] = {
@@ -174,9 +174,9 @@ def build_macro_classes(BaseClass):
             if not self.init_config:
                 # catch up on params and returns
                 for p in self.macro_script.parameters:
-                    self.create_input(p['type'], p['label'])
+                    self.create_input(type_=p['type'], label=p['label'])
                 for r in self.macro_script.returns:
-                    self.create_output(r['type'], r['label'])
+                    self.create_output(type_=r['type'], label=r['label'])
 
         def update_event(self, inp=-1):
 
